module MdToHtmlTest where

import MdToHTML
import Test.HUnit

check_equal :: String -> String -> String -> Test
check_equal desc expected actual = TestCase (assertEqual desc expected actual)

convert :: String -> String
convert md = show . fst $ leftmostLongestParse parseDocument md

headerTests =
  TestList
    [ check_equal "Should convert H1 heading" "<h1>Hello</h1>" (convert "# Hello"),
      check_equal "Should convert H2 heading" "<h2>Hello</h2>" (convert "## Hello"),
      check_equal "Should convert H3 heading" "<h3>Hello</h3>" (convert "### Hello"),
      check_equal "Should convert H4 heading" "<h4>Hello</h4>" (convert "#### Hello"),
      check_equal "Should convert H5 heading" "<h5>Hello</h5>" (convert "##### Hello"),
      check_equal "Should convert H6 heading" "<h6>Hello</h6>" (convert "###### Hello")
    ]

boldTests =
  TestList
    [ check_equal "Should convert bold" "<p><b>Hello</b></p>" (convert "__Hello__"),
      check_equal "Should convert italic" "<p><i>Hello</i></p>" (convert "_Hello_"),
      check_equal "Should convert bold and italic in a sentence" "<p>It <i>is</i> a <b>wonderful</b> day</p>" (convert "It _is_ a __wonderful__ day")
    ]

integrationTests =
  TestList
    [ check_equal "Integration 1" "<h1>Sample Markdown</h1><p>This is some basic, sample markdown.</p><h2><b>Second</b> <i>Heading</i></h2>" (convert "# Sample Markdown\n\n This is some basic, sample markdown.\n\n  ## __Second__ _Heading_"),
      check_equal "Integration 2" "<p><b>Hello</b> <i>World</i></p>" (convert "__Hello__\n_World_"),
      check_equal "Integration 3" "<h1>Hello</h1><p>World</p>" (convert "# Hello\nWorld"),
      check_equal "Integration 4" "<h1>Hello</h1>" (convert "# Hello\n")
    ]

tests =
  TestList
    [ headerTests,
      boldTests,
      integrationTests
    ]

runTests = runTestTT tests
